from collections import namedtuple, Mapping

Numeric = namedtuple('Numeric', 'name numeric')


class NumericsDict(Mapping):
    def __init__(self, *args):
        super().__init__()
        self.data = args
        self.names = {num.name: num for num in args}
        self.nums = {num.numeric: num for num in args}
        self.values = {str(num.numeric).zfill(3): num for num in args}

    def __iter__(self):
        return iter(self.data)

    def __len__(self):
        return len(self.names)

    def __getitem__(self, key):
        try:
            return self.names[str(key).upper()]
        except KeyError:
            try:
                return self.nums[key]
            except KeyError:
                return self.values[key]

    def __getattr__(self, item):
        try:
            return self.names[str(item).upper()]
        except LookupError:
            raise AttributeError(item)


numerics = NumericsDict(
    Numeric('RPL_WELCOME', 1),
    Numeric('RPL_YOURHOST', 2),
    Numeric('RPL_CREATED', 3),
    Numeric('RPL_MYINFO', 4),
    Numeric('RPL_BOUNCE', 5),
    Numeric('RPL_TRACELINK', 200),
    Numeric('RPL_TRACECONNECTING', 201),
    Numeric('RPL_TRACEHANDSHAKE', 202),
    Numeric('RPL_TRACEUNKNOWN', 203),
    Numeric('RPL_TRACEOPERATOR', 204),
    Numeric('RPL_TRACEUSER', 205),
    Numeric('RPL_TRACESERVER', 206),
    Numeric('RPL_TRACESERVICE', 207),
    Numeric('RPL_TRACENEWTYPE', 208),
    Numeric('RPL_TRACECLASS', 209),
    Numeric('RPL_TRACERECONNECT', 210),
    Numeric('RPL_STATSLINKINFO', 211),
    Numeric('RPL_STATSCOMMANDS', 212),
    Numeric('RPL_STATSCLINE', 213),
    Numeric('RPL_STATSNLINE', 214),
    Numeric('RPL_STATSILINE', 215),
    Numeric('RPL_STATSKLINE', 216),
    Numeric('RPL_STATSQLINE', 217),
    Numeric('RPL_STATSYLINE', 218),
    Numeric('RPL_ENDOFSTATS', 219),
    Numeric('RPL_UMODEIS', 221),
    Numeric('RPL_SERVICEINFO', 231),
    Numeric('RPL_ENDOFSERVICES', 232),
    Numeric('RPL_SERVICE', 233),
    Numeric('RPL_SERVLIST', 234),
    Numeric('RPL_SERVLISTEND', 235),
    Numeric('RPL_STATSVLINE', 240),
    Numeric('RPL_STATSLLINE', 241),
    Numeric('RPL_STATSUPTIME', 242),
    Numeric('RPL_STATSOLINE', 243),
    Numeric('RPL_STATSHLINE', 244),
    Numeric('RPL_STATSPING', 246),
    Numeric('RPL_STATSBLINE', 247),
    Numeric('RPL_STATSDLINE', 250),
    Numeric('RPL_LUSERCLIENT', 251),
    Numeric('RPL_LUSEROP', 252),
    Numeric('RPL_LUSERUNKNOWN', 253),
    Numeric('RPL_LUSERCHANNELS', 254),
    Numeric('RPL_LUSERME', 255),
    Numeric('RPL_ADMINME', 256),
    Numeric('RPL_ADMINLOC1', 257),
    Numeric('RPL_ADMINLOC2', 258),
    Numeric('RPL_ADMINEMAIL', 259),
    Numeric('RPL_TRACELOG', 261),
    Numeric('RPL_TRACEEND', 262),
    Numeric('RPL_TRYAGAIN', 263),
    Numeric('RPL_NONE', 300),
    Numeric('RPL_AWAY', 301),
    Numeric('RPL_USERHOST', 302),
    Numeric('RPL_ISON', 303),
    Numeric('RPL_UNAWAY', 305),
    Numeric('RPL_NOWAWAY', 306),
    Numeric('RPL_WHOISUSER', 311),
    Numeric('RPL_WHOISSERVER', 312),
    Numeric('RPL_WHOISOPERATOR', 313),
    Numeric('RPL_WHOWASUSER', 314),
    Numeric('RPL_ENDOFWHO', 315),
    Numeric('RPL_WHOISCHANOP', 316),
    Numeric('RPL_WHOISIDLE', 317),
    Numeric('RPL_ENDOFWHOIS', 318),
    Numeric('RPL_WHOISCHANNELS', 319),
    Numeric('RPL_LISTSTART', 321),
    Numeric('RPL_LIST', 322),
    Numeric('RPL_LISTEND', 323),
    Numeric('RPL_CHANNELMODEIS', 324),
    Numeric('RPL_UNIQOPIS', 325),
    Numeric('RPL_NOTOPIC', 331),
    Numeric('RPL_TOPIC', 332),
    Numeric('RPL_INVITING', 341),
    Numeric('RPL_SUMMONING', 342),
    Numeric('RPL_INVITELIST', 346),
    Numeric('RPL_ENDOFINVITELIST', 347),
    Numeric('RPL_EXCEPTLIST', 348),
    Numeric('RPL_ENDOFEXCEPTLIST', 349),
    Numeric('RPL_VERSION', 351),
    Numeric('RPL_WHOREPLY', 352),
    Numeric('RPL_NAMREPLY', 353),
    Numeric('RPL_KILLDONE', 361),
    Numeric('RPL_CLOSING', 362),
    Numeric('RPL_CLOSEEND', 363),
    Numeric('RPL_LINKS', 364),
    Numeric('RPL_ENDOFLINKS', 365),
    Numeric('RPL_ENDOFNAMES', 366),
    Numeric('RPL_BANLIST', 367),
    Numeric('RPL_ENDOFBANLIST', 368),
    Numeric('RPL_ENDOFWHOWAS', 369),
    Numeric('RPL_INFO', 371),
    Numeric('RPL_MOTD', 372),
    Numeric('RPL_INFOSTART', 373),
    Numeric('RPL_ENDOFINFO', 374),
    Numeric('RPL_MOTDSTART', 375),
    Numeric('RPL_ENDOFMOTD', 376),
    Numeric('RPL_YOUREOPER', 381),
    Numeric('RPL_REHASHING', 382),
    Numeric('RPL_YOURESERVICE', 383),
    Numeric('RPL_MYPORTIS', 384),
    Numeric('RPL_TIME', 391),
    Numeric('RPL_USERSSTART', 392),
    Numeric('RPL_USERS', 393),
    Numeric('RPL_ENDOFUSERS', 394),
    Numeric('RPL_NOUSERS', 395),
    Numeric('ERR_NOSUCHNICK', 401),
    Numeric('ERR_NOSUCHSERVER', 402),
    Numeric('ERR_NOSUCHCHANNEL', 403),
    Numeric('ERR_CANNOTSENDTOCHAN', 404),
    Numeric('ERR_TOOMANYCHANNELS', 405),
    Numeric('ERR_WASNOSUCHNICK', 406),
    Numeric('ERR_TOOMANYTARGETS', 407),
    Numeric('ERR_NOSUCHSERVICE', 408),
    Numeric('ERR_NOORIGIN', 409),
    Numeric('ERR_NORECIPIENT', 411),
    Numeric('ERR_NOTEXTTOSEND', 412),
    Numeric('ERR_NOTOPLEVEL', 413),
    Numeric('ERR_WILDTOPLEVEL', 414),
    Numeric('ERR_BADMASK', 415),
    Numeric('ERR_UNKNOWNCOMMAND', 421),
    Numeric('ERR_NOMOTD', 422),
    Numeric('ERR_NOADMININFO', 423),
    Numeric('ERR_FILEERROR', 424),
    Numeric('ERR_NONICKNAMEGIVEN', 431),
    Numeric('ERR_ERRONEUSNICKNAME', 432),
    Numeric('ERR_NICKNAMEINUSE', 433),
    Numeric('ERR_NICKCOLLISION', 436),
    Numeric('ERR_UNAVAILRESOURCE', 437),
    Numeric('ERR_USERNOTINCHANNEL', 441),
    Numeric('ERR_NOTONCHANNEL', 442),
    Numeric('ERR_USERONCHANNEL', 443),
    Numeric('ERR_NOLOGIN', 444),
    Numeric('ERR_SUMMONDISABLED', 445),
    Numeric('ERR_USERSDISABLED', 446),
    Numeric('ERR_NOTREGISTERED', 451),
    Numeric('ERR_NEEDMOREPARAMS', 461),
    Numeric('ERR_ALREADYREGISTERED', 462),
    Numeric('ERR_NOPERMFORHOST', 463),
    Numeric('ERR_PASSWDMISMATCH', 464),
    Numeric('ERR_YOUREBANNEDCREEP', 465),
    Numeric('ERR_YOUWILLBEBANNED', 466),
    Numeric('ERR_KEYSET', 467),
    Numeric('ERR_CHANNELISFULL', 471),
    Numeric('ERR_UNKNOWNMODE', 472),
    Numeric('ERR_INVITEONLYCHAN', 473),
    Numeric('ERR_BANNEDFROMCHAN', 474),
    Numeric('ERR_BADCHANNELKEY', 475),
    Numeric('ERR_BADCHANMASK', 476),
    Numeric('ERR_NOCHANMODES', 477),
    Numeric('ERR_BANLISTFULL', 478),
    Numeric('ERR_NOPRIVILEGES', 481),
    Numeric('ERR_CHANOPRIVSNEEDED', 482),
    Numeric('ERR_CANTKILLSERVER', 483),
    Numeric('ERR_RESTRICTED', 484),
    Numeric('ERR_UNIQOPRIVSNEEDED', 485),
    Numeric('ERR_NOOPERHOST', 491),
    Numeric('ERR_NOSERVICEHOST', 492),
    Numeric('ERR_UMODEUNKNOWNFLAG', 501),
    Numeric('ERR_USERSDONTMATCH', 502),
)



class FrozenDict(dict):
    __slots__ = ("__hash",)

    __setitem__ = None
    __delitem__ = None

    pop = None
    popitem = None

    clear = None
    setdefault = None
    update = None

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.__hash = None

    def copy(self, **kwargs):
        return self.__class__(self, **kwargs)

    def __hash__(self):
        if self.__hash is None:
            self.__hash = hash(tuple(self.items()))

        return self.__hash



"""
Simple IRC line parser

Backported from async-irc (https://github.com/snoonetIRC/async-irc.git)
"""

import re
from abc import ABCMeta, abstractmethod
from collections import namedtuple

from irclib.errors import ParseError
from irclib.util.frozendict import FrozenDict

TAGS_SENTINEL = '@'
TAGS_SEP = ';'
TAG_VALUE_SEP = '='

PREFIX_SENTINEL = ':'
PREFIX_USER_SEP = '!'
PREFIX_HOST_SEP = '@'

PARAM_SEP = ' '
TRAIL_SENTINEL = ':'

CAP_SEP = ' '
CAP_VALUE_SEP = '='

PREFIX_RE = re.compile(r'^:?(?P<nick>.+?)(?:!(?P<user>.+?))?(?:@(?P<host>.+?))?$')

TAG_VALUE_ESCAPES = {
    '\\s': ' ',
    '\\:': ';',
    '\\r': '\r',
    '\\n': '\n',
    '\\\\': '\\',
}

TAG_VALUE_UNESCAPES = {
    unescaped: escaped
    for escaped, unescaped in TAG_VALUE_ESCAPES.items()
}


class Parseable(metaclass=ABCMeta):
    """Abstract class for parseable objects"""

    @abstractmethod
    def __str__(self):
        raise NotImplementedError

    @staticmethod
    @abstractmethod
    def parse(text):
        """Parse the object from a string
        :type text: str
        """
        raise NotImplementedError


_Cap = namedtuple('_Cap', 'name value')


class Cap(Parseable, _Cap):
    """Represents a CAP entity as defined in IRCv3.2"""

    def __new__(cls, name, value=None):
        return _Cap.__new__(cls, name, value)

    def __str__(self):
        """
        :rtype: str
        """
        if self.value:
            return CAP_VALUE_SEP.join(self)

        return self.name

    @staticmethod
    def parse(text):
        """Parse a CAP entity from a string
        :type text: str
        """
        name, _, value = text.partition(CAP_VALUE_SEP)
        return Cap(name, value or None)


class CapList(Parseable, tuple):
    """Represents a list of CAP entities"""

    def __str__(self):
        """
        :rtype: str
        """
        return CAP_SEP.join(map(str, self))

    @staticmethod
    def parse(text):
        """Parse a list of CAPs from a string
        :type text: str
        """
        if text.startswith(':'):
            text = text[1:]  # Remove leading colon

        return CapList(map(Cap.parse, text.split(CAP_SEP)))


_MessageTag = namedtuple('_MessageTag', 'name value')


class MessageTag(Parseable, _MessageTag):
    """
    Basic class to wrap a message tag
    """

    def __new__(cls, name, value=None):
        return _MessageTag.__new__(cls, name, value)

    @staticmethod
    def unescape(value):
        """
        Replace the escaped characters in a tag value with their literals
        :param value: Escaped string
        :return: Unescaped string
        """
        new_value = ""
        found = False
        for i in range(len(value)):
            if found:
                found = False
                continue

            if value[i] == '\\':
                if i + 1 >= len(value):
                    raise ParseError("Unexpected end of string while parsing: {}".format(value))

                new_value += TAG_VALUE_ESCAPES[value[i:i + 2]]
                found = True
            else:
                new_value += value[i]

        return new_value

    @staticmethod
    def escape(value):
        """
        Replace characters with their escaped variants
        :param value: The raw string
        :return: The escaped string
        """
        return "".join(TAG_VALUE_UNESCAPES.get(c, c) for c in value)

    def __str__(self):
        if self.value:
            return "{}{}{}".format(
                self.name, TAG_VALUE_SEP, self.escape(self.value)
            )

        return self.name

    def __eq__(self, other):
        if isinstance(other, str):
            return self == self.parse(other)

        if isinstance(other, type(self)):
            return tuple(self) == tuple(other)

        return NotImplemented

    @staticmethod
    def parse(text):
        """
        Parse a tag from a string
        :type text: str
        :param text: The basic tag string
        :return: The MessageTag object
        """
        name, _, value = text.partition(TAG_VALUE_SEP)
        if value:
            value = MessageTag.unescape(value)

        return MessageTag(name, value or None)


class TagList(Parseable, FrozenDict):
    """Object representing the list of message tags on a line"""

    def __init__(self, tags):
        super().__init__((tag.name, tag) for tag in tags)

    def __str__(self):
        return TAGS_SENTINEL + TAGS_SEP.join(map(str, self.values()))

    @staticmethod
    def parse(text):
        """
        Parse the list of tags from a string
        :type text: str
        :param text: The string to parse
        :return: The parsed object
        """
        return TagList(
            map(MessageTag.parse, filter(None, text.split(TAGS_SEP)))
        )


_Prefix = namedtuple('_Prefix', 'nick user host')


class Prefix(Parseable, _Prefix):
    """
    Object representing the prefix of a line
    """

    def __new__(cls, nick, user=None, host=None):
        return _Prefix.__new__(cls, nick, user, host)

    @property
    def mask(self):
        """
        The complete n!u@h mask
        """
        mask = self.nick
        if self.user:
            mask += PREFIX_USER_SEP + self.user

        if self.host:
            mask += PREFIX_HOST_SEP + self.host

        return mask

    def __str__(self):
        return PREFIX_SENTINEL + self.mask

    def __bool__(self):
        return bool(self.nick)

    @staticmethod
    def parse(text):
        """
        Parse the prefix from a string
        :type text: str
        :param text: String to parse
        :return: Parsed Object
        """
        if not text:
            return Prefix('', None, None)

        match = PREFIX_RE.match(text)
        if not match:
            raise ParseError("Invalid IRC prefix format")

        nick, user, host = match.groups()
        return Prefix(nick, user, host)


class ParamList(Parseable, tuple):
    """
    An object representing the parameter list from a line
    """

    def __new__(cls, seq, has_trail=False):
        seq = list(seq)
        has_trail = has_trail or (seq and PARAM_SEP in seq[-1])
        if seq:
            seq[-1] = (TRAIL_SENTINEL if has_trail else "") + seq[-1]

        return tuple.__new__(cls, seq)

    @property
    def has_trail(self):
        return self and self[-1][:1] == TRAIL_SENTINEL

    def __str__(self):
        return PARAM_SEP.join(self)

    @staticmethod
    def parse(text):
        """
        Parse a list of parameters
        :type text: str
        :param text: The list of parameters
        :return: The parsed object
        """
        args = []
        has_trail = False
        while text:
            if text[0] == TRAIL_SENTINEL:
                args.append(text[1:])
                has_trail = True
                break

            arg, _, text = text.partition(PARAM_SEP)
            if arg:
                args.append(arg)

        return ParamList(args, has_trail=has_trail)


_Message = namedtuple('_Message', 'tags prefix command parameters')


class Message(Parseable, _Message):
    """
    An object representing a parsed IRC line
    """

    def __new__(cls, tags=None, prefix=None, command=None, parameters=None):
        return _Message.__new__(cls, tags, prefix, command, parameters)

    def __str__(self):
        return PARAM_SEP.join(map(str, filter(None, self)))

    def __bool__(self):
        return any(self)

    def __eq__(self, other):
        if isinstance(other, (str, bytes)):
            return self == Message.parse(other)

        if isinstance(other, Message):
            return tuple(self) == tuple(other)

        return NotImplemented

    @staticmethod
    def parse(text):
        """Parse an IRC message in to objects
        :type text: str
        """
        if isinstance(text, bytes):
            text = text.decode(errors="ignore")

        tags = ''
        prefix = ''
        if text.startswith(TAGS_SENTINEL):
            tags, _, text = text.partition(PARAM_SEP)

        if text.startswith(PREFIX_SENTINEL):
            prefix, _, text = text.partition(PARAM_SEP)

        command, _, params = text.partition(PARAM_SEP)
        tags = TagList.parse(tags[1:])
        prefix = Prefix.parse(prefix[1:])
        command = command.upper()
        params = ParamList.parse(params)
        return Message(tags, prefix, command, params)



from collections import Mapping


class Command:
    def __init__(self, name, args=None, min_args=0, max_args=None):
        self.name = name
        self.args = args
        self.min_args = min_args
        self.max_args = max_args


class LookupDict(Mapping):
    def __init__(self, *commands):
        for command in commands:
            setattr(self, command.name.lower(), command)
            setattr(self, command.name.upper(), command)

    def __getitem__(self, key):
        try:
            return getattr(self, key)
        except AttributeError as e:
            raise KeyError(key) from e

    def __len__(self):
        raise NotImplementedError

    def __iter__(self):
        raise NotImplementedError


# Commands sent from the client to the server
client_commands = LookupDict(
    Command('PRIVMSG', "<target> <content>"),
    Command('NOTICE', "<target> <content>"),
)




# coding=utf-8
"""
IRC string utils
"""
import operator
from functools import wraps


class Casemap(tuple):
    __slots__ = ()

    def __new__(cls, lower, upper):
        return tuple.__new__(cls, (lower, upper))

    @property
    def lower_table(self):
        return str.maketrans(self.lower, self.upper)

    @property
    def upper_table(self):
        return str.maketrans(self.upper, self.lower)

    @property
    def lower(self):
        return self[0]

    @property
    def upper(self):
        return self[1]


RFC1459 = Casemap("".join(map(chr, range(65, 95))), "".join(map(chr, range(97, 127))))
STRICT_RFC1459 = Casemap("".join(map(chr, range(65, 94))), "".join(map(chr, range(97, 126))))
ASCII = Casemap("".join(map(chr, range(65, 91))), "".join(map(chr, range(97, 123))))

sentinel = object()


class cached_property:
    def __init__(self, wrapped):
        self.wrapped = wrapped
        try:
            self.__doc__ = wrapped.__doc__
        except AttributeError:  # pragma: no cover
            self.__doc__ = ""

        self.name = wrapped.__name__

    def __get__(self, inst, owner, _sentinel=sentinel):
        if inst is None:
            return self

        val = inst._cache.get(self.name, _sentinel)
        if val is not _sentinel:
            return val

        inst._cache[self.name] = val = self.wrapped(inst)
        return val

    def __set__(self, inst, value):
        raise AttributeError("cached property is read-only")


class cached_method(cached_property):
    def __get__(self, inst, owner, _sentinel=sentinel):
        return lambda: cached_property.__get__(self, inst, owner, _sentinel)


def type_wrap(super_index, wrap_out=True):
    def _decorate(func):
        @wraps(func)
        def wrapper(self, *args, **kwargs):
            if not isinstance(args[super_index], String):
                args = list(args)
                args[super_index] = self._wrap(args[super_index])

            if wrap_out:
                return self._wrap(func(self, *args, **kwargs))

            return func(self, *args, **kwargs)

        return wrapper

    return lambda func: _decorate(func)


class String(str):
    __slots__ = ("_casemap", "_cache")

    def _wrap(self, value):
        return self.__class__(value, self.casemap)

    @cached_method
    def __hash__(self):
        return hash(str(self.lower()))

    def __new__(cls, value='', casemap=None):
        return str.__new__(cls, value)

    def __init__(self, value='', casemap=None):
        super().__init__()
        self._cache = dict(casemap=casemap)

    def __internal_cmp(self, other, cmp):
        if isinstance(other, String):
            return cmp(str(self.casefold()), str(other.casefold()))

        return cmp(self, self._wrap(other))

    def __lt__(self, other):
        return self.__internal_cmp(other, operator.lt)

    def __le__(self, other):
        return self.__internal_cmp(other, operator.le)

    def __eq__(self, other):
        return self.__internal_cmp(other, operator.eq)

    def __ne__(self, other):
        return self.__internal_cmp(other, operator.ne)

    def __gt__(self, other):
        return self.__internal_cmp(other, operator.gt)

    def __ge__(self, other):
        return self.__internal_cmp(other, operator.ge)

    @type_wrap(0, False)
    def __contains__(self, item):
        return item.casefold() in str(self.casefold())

    def __getitem__(self, item):
        return self._wrap(super().__getitem__(item))

    def translate(self, table):
        return self._wrap(super().translate(table))

    @cached_method
    def capitalize(self):
        return self[:1].upper() + self[1:].lower()

    @cached_method
    def casefold(self):
        return self.lower()

    @cached_method
    def lower(self):
        return self.translate(self.casemap.lower_table)

    @cached_method
    def upper(self):
        return self.translate(self.casemap.upper_table)

    @type_wrap(0)
    def count(self, c, start=None, end=None):
        return str(self.casefold()).count(c.casefold(), start, end)

    @type_wrap(0)
    def startswith(self, prefix, start=None, end=None):
        return str(self.casefold()).startswith(prefix.lower(), start, end)

    @type_wrap(0)
    def endswith(self, suffix, start=None, end=None):
        return str(self.casefold()).endswith(suffix.casefold(), start, end)

    @type_wrap(0)
    def find(self, sub, start=None, end=None):
        return str(self.casefold()).find(sub.casefold(), start, end)

    @type_wrap(0)
    def rfind(self, sub, start=None, end=None):
        return str(self.casefold()).rfind(sub.casefold(), start, end)

    @type_wrap(0)
    def index(self, sub, start=None, end=None):
        return str(self.casefold()).index(sub.casefold(), start, end)

    @type_wrap(0)
    def rindex(self, sub, start=None, end=None):
        return str(self.casefold()).rindex(sub.casefold(), start, end)

    @type_wrap(0, False)
    def partition(self, sep):
        pos = self.find(sep)
        if pos < 0:
            return self, self._wrap(""), self._wrap("")

        return self[:pos], self[pos:pos + len(sep)], self[pos + len(sep):]

    @type_wrap(0, False)
    def rpartition(self, sep):
        pos = self.rfind(sep)
        if pos < 0:
            return self._wrap(""), self._wrap(""), self

        return self[:pos], self[pos:pos + len(sep)], self[pos + len(sep):]

    def replace(self, old, new, count=-1):
        raise NotImplementedError

    def strip(self, chars=None):
        return self.lstrip(chars).rstrip(chars)

    def lstrip(self, chars=None):
        raise NotImplementedError

    def rstrip(self, chars=None):
        raise NotImplementedError

    @cached_method
    def swapcase(self):
        tr = self.casemap.lower_table + self.casemap.upper_table

        return self.translate(tr)

    def title(self):
        raise NotImplementedError

    def split(self, sep=None, maxsplit=-1):
        raise NotImplementedError

    def rsplit(self, sep=None, maxsplit=-1):
        raise NotImplementedError

    @cached_property
    def casemap(self):
        raise RuntimeError("String.casefold property not properly cached")



# coding=utf-8
from setuptools import setup

setup(
    name='py-irclib',
    version='0.1.4',
    python_requires=">=3.3",
    description="A simple library for working with the IRC protocol",
    url='https://github.com/TotallyNotRobots/py-irclib',
    author='linuxdaemon',
    author_email='linuxdaemon@snoonet.org',
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.3',
    ],
    keywords='irc irc-parser',
    packages=['irclib', 'irclib.util'],
    install_requires=[],
    setup_requires=['pytest-runner', 'pytest-cov', 'pytest-pep8'],
    tests_require=['pytest', 'pytest-cov', 'pytest-pep8'],
)
